summaryrefslogtreecommitdiff
path: root/include/mbgl/storage/resource_options.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'include/mbgl/storage/resource_options.hpp')
-rw-r--r--include/mbgl/storage/resource_options.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/mbgl/storage/resource_options.hpp b/include/mbgl/storage/resource_options.hpp
index 53350f55c2..00dc6e10df 100644
--- a/include/mbgl/storage/resource_options.hpp
+++ b/include/mbgl/storage/resource_options.hpp
@@ -106,10 +106,10 @@ public:
/**
* @brief Gets the previously set (or default) support for cache-only requests.
*
* @param Whether or not cache-only requests are supported.
* @return reference to ResourceOptions for chaining options together.
*/
- ResourceOptions& withCacheOnlyRequestsSupport(bool);
+ ResourceOptions& withCacheOnlyRequestsSupport(bool cacheOnly);
/**
* @brief Sets the platform context. A platform context is usually an object
@@ -106,10 +106,10 @@ public:
* @brief Gets the previously set (or default) support for cache-only requests.
*
- * @param Whether or not cache-only requests are supported.
+ * @param cacheOnly Whether or not cache-only requests are supported.
* @return reference to ResourceOptions for chaining options together.
*/